@@ -1,14 +1,13 @@
-from .Connection import Connection
-
 import dir_ops as do
 import os
 
 _Dir = do.Dir( os.path.abspath( __file__ ) ).ascend()   #Dir that contains the package 
-_src_Dir = _Dir.ascend()                                  #src Dir that is one above
-_repo_Dir = _src_Dir.ascend()                    
-_cwd_Dir = do.Dir( do.get_cwd() )
-
-
-cred_dict = {}
 
+from .Connection import Connection
+from .Client import Client
 from . import s3 
+
+import aws_credentials
+
+client = Client( connection_kwargs=aws_credentials.cred_dict )
+
